Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(793)

Unified Diff: pkg/analyzer/lib/task/model.dart

Issue 1012993002: Rename ContributionPoint and error result (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analyzer/lib/task/model.dart
diff --git a/pkg/analyzer/lib/task/model.dart b/pkg/analyzer/lib/task/model.dart
index dc4e0a25b0d59ccb62f8f0e9815af7a5cf0fefbc..9de42f39ce7cfbad8c3778be58781fd43be61e08 100644
--- a/pkg/analyzer/lib/task/model.dart
+++ b/pkg/analyzer/lib/task/model.dart
@@ -227,15 +227,16 @@ abstract class AnalysisTask {
*
* Clients are not expected to subtype this class.
*/
-abstract class ContributionPoint<V> extends ResultDescriptor<V> {
+abstract class CompositeResultDescriptor<V> extends ResultDescriptor<V> {
/**
* Initialize a newly created contribution point to have the given [name].
*/
- factory ContributionPoint(String name) = ContributionPointImpl;
+ factory CompositeResultDescriptor(
+ String name) = CompositeResultDescriptorImpl;
/**
* Return a list containing the descriptors of the results that are unioned
- * together to comprise the value of this result.
+ * together to compose the value of this result.
*
* Clients must not modify the returned list.
*/
@@ -250,10 +251,10 @@ abstract class ContributionPoint<V> extends ResultDescriptor<V> {
abstract class ResultDescriptor<V> {
/**
* Initialize a newly created analysis result to have the given [name]. If a
* contribution point is specified, then this result will contribute to it.
*/
factory ResultDescriptor(String name, V defaultValue,
- {ContributionPoint<V> contributesTo}) = ResultDescriptorImpl;
+ {CompositeResultDescriptor<V> contributesTo}) = ResultDescriptorImpl;
/**
* Return the default value for results described by this descriptor.
@@ -227,15 +227,16 @@ abstract class AnalysisTask {
/**
- * Initialize a newly created contribution point to have the given [name].
+ * Initialize a newly created composite result to have the given [name].
*/
@@ -250,10 +251,10 @@ abstract class ContributionPoint<V> extends ResultDescriptor<V> {
/**
* Initialize a newly created analysis result to have the given [name]. If a
- * contribution point is specified, then this result will contribute to it.
+ * composite result is specified, then this result will contribute to it.
*/
factory ResultDescriptor(String name, V defaultValue,

Powered by Google App Engine
This is Rietveld 408576698